<div align="center">
<img src="https://github.com/sepandhaghighi/clox/raw/main/otherfiles/logo.png" width="450">
<h1>Clox: A Geeky Clock for Terminal Enthusiasts</h1>
<br/>
<a href="https://badge.fury.io/py/clox"><img src="https://badge.fury.io/py/clox.svg" alt="PyPI version"></a>
<a href="https://www.python.org/"><img src="https://img.shields.io/badge/built%20with-Python3-green.svg" alt="built with Python3"></a>
<a href="https://github.com/sepandhaghighi/clox"><img alt="GitHub repo size" src="https://img.shields.io/github/repo-size/sepandhaghighi/clox"></a>
</div>			
				
## Overview	

<p align="justify">					
Clox is a terminal-based clock application designed for terminal enthusiasts who appreciate simplicity, elegance, and productivity within their command-line environment. Whether you're coding, monitoring tasks, or simply enjoying the terminal aesthetic, Clox brings a stylish and customizable time display to your workspace.
</p>

<table>
	<tr>
		<td align="center">PyPI Counter</td>
		<td align="center"><a href="http://pepy.tech/project/clox"><img src="http://pepy.tech/badge/clox"></a></td>
	</tr>
	<tr>
		<td align="center">Github Stars</td>
		<td align="center"><a href="https://github.com/sepandhaghighi/clox"><img src="https://img.shields.io/github/stars/sepandhaghighi/clox.svg?style=social&label=Stars"></a></td>
	</tr>
</table>



<table>
	<tr> 
		<td align="center">Branch</td>
		<td align="center">main</td>	
		<td align="center">dev</td>	
	</tr>
	<tr>
		<td align="center">CI</td>
		<td align="center"><img src="https://github.com/sepandhaghighi/clox/actions/workflows/test.yml/badge.svg?branch=main"></td>
		<td align="center"><img src="https://github.com/sepandhaghighi/clox/actions/workflows/test.yml/badge.svg?branch=dev"></td>
	</tr>
</table>


<table>
	<tr> 
		<td align="center">Code Quality</td>
		<td align="center"><a href="https://www.codefactor.io/repository/github/sepandhaghighi/clox"><img src="https://www.codefactor.io/repository/github/sepandhaghighi/clox/badge" alt="CodeFactor"></a></td>
		<td align="center"><a href="https://app.codacy.com/gh/sepandhaghighi/clox/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade"><img src="https://app.codacy.com/project/badge/Grade/4cd4cd3b20b1474fb674823b1b417b76"></a></td>
		<td align="center"><a href="https://codebeat.co/projects/github-com-sepandhaghighi-clox-main"><img alt="codebeat badge" src="https://codebeat.co/badges/19394d3a-009b-401b-b376-24a325ef2fdf"></a></td>
	</tr>
</table>


## Installation		

### Source Code
- Download [Version 0.6](https://github.com/sepandhaghighi/clox/archive/v0.6.zip) or [Latest Source](https://github.com/sepandhaghighi/clox/archive/dev.zip)
- `pip install .`				

### PyPI

- Check [Python Packaging User Guide](https://packaging.python.org/installing/)     
- `pip install clox==0.6`						


## Usage

ℹ️ You can use `clox` or `python -m clox` to run this program

### Version

```console
clox --version
```

### Info

```console
clox --info
```

### Basic

ℹ️ Press `Ctrl + C` to exit

```console
clox
```

### Face

```console
clox --face=3
```
* Use `--face=-1` for random mode
* [Faces List](https://github.com/sepandhaghighi/clox/blob/main/FACES.md)
* `clox --faces-list`

### Timezone

```console
clox --timezone="Etc/GMT+7"
```
* [Timezones List](https://github.com/sepandhaghighi/clox/blob/main/TIMEZONES.md)
* `clox --timezones-list`

### Vertical/Horizontal Shift

ℹ️ The vertical and horizontal shift both have default values of `0`

```console
clox --v-shift=20 --h-shift=30
```

### No Blink

Disable blinking mode

```console
clox --no-blink
```

### Hide Date

In this mode, the date will not be shown

```console
clox --hide-date
```

### Hide Timezone

In this mode, the timezone will not be shown

```console
clox --hide-timezone
```

### AM/PM Mode

In this mode, the clock will be displayed in 12-hour format

```console
clox --am-pm
```

### Vertical Mode

```console
clox --vertical
```

### Calendar Mode

In this mode, the calendar will be displayed

ℹ️ Valid choices: [`month`, `year`]

```console
clox --calendar=month
```

## Screen Record

<div align="center">

<img src="https://github.com/sepandhaghighi/clox/raw/main/otherfiles/help.gif">

</div>

## Issues & Bug Reports			

Just fill an issue and describe it. We'll check it ASAP!

- Please complete the issue template
 			

## Show Your Support
								
<h3>Star This Repo</h3>					

Give a ⭐️ if this project helped you!

<h3>Donate to Our Project</h3>	

<h4>Bitcoin</h4>
1KtNLEEeUbTEK9PdN6Ya3ZAKXaqoKUuxCy
<h4>Ethereum</h4>
0xcD4Db18B6664A9662123D4307B074aE968535388
<h4>Litecoin</h4>
Ldnz5gMcEeV8BAdsyf8FstWDC6uyYR6pgZ
<h4>Doge</h4>
DDUnKpFQbBqLpFVZ9DfuVysBdr249HxVDh
<h4>Tron</h4>
TCZxzPZLcJHr2qR3uPUB1tXB6L3FDSSAx7
<h4>Ripple</h4>
rN7ZuRG7HDGHR5nof8nu5LrsbmSB61V1qq
<h4>Binance Coin</h4>
bnb1zglwcf0ac3d0s2f6ck5kgwvcru4tlctt4p5qef
<h4>Tether</h4>
0xcD4Db18B6664A9662123D4307B074aE968535388
<h4>Dash</h4>
Xd3Yn2qZJ7VE8nbKw2fS98aLxR5M6WUU3s
<h4>Stellar</h4>		
GALPOLPISRHIYHLQER2TLJRGUSZH52RYDK6C3HIU4PSMNAV65Q36EGNL
<h4>Zilliqa</h4>
zil1knmz8zj88cf0exr2ry7nav9elehxfcgqu3c5e5
<h4>Coffeete</h4>
<a href="http://www.coffeete.ir/opensource">
<img src="http://www.coffeete.ir/images/buttons/lemonchiffon.png" style="width:260px;" />
</a>

